* Numbers from Chapter 5
clear all 
set more off 

**************************
*Fraction of Authoritarian parents, p. 165-166
**************************
use WVS_OECD,clear

collapse authoritarian authoritative permissive, by(country wave year)

*Australia
list authoritarian authoritative year if country=="Australia"
*Japan
list authoritarian authoritative year if country=="Japan"
*Sweden
list authoritarian authoritative year if country=="Sweden"
*Spain
list authoritarian authoritative year if country=="Spain"

******************************************************
*PSID-CDS spanking, p. 175
******************************************************

clear all
use CDS_analysis.dta

tab ever_spank_97,m
mean ever_spank_97 [pweight=CH97PRWT]

*Mean values
mean PCGreligion1_97 [pweight=CH97PRWT], over(ever_spank_97)

*SIMPLE REGRESSION ANALYSIS
logit ever_spank_97 Cltotfam_inc_97 PCG_yed_97 CagePCGint_97 PCG_age_97 Cfemale Cblack Chisp Cother PCGreligion1_97 [pweight=CH97PRWT] if Cregion_97!=6, vce(cluster ER12221) or


******************************
*RELIGIOSITY IN THE US, p. 176
******************************

clear all
set more off 
use WVS_OECD

keep if country=="United States"

tab F025,m
* PArenting: 1 = permissive, 2= authoritative, 3 = authoritarian

* Define Religions:
gen non_religious=0
replace non_religious=. if F025<0
replace non_religious=1 if F025==0 & (A006==3|A006==4)

gen catholic=0
replace catholic=. if F025<0
replace catholic=1 if F025==15|F025==29|F025==64

gen protestant=0
replace protestant=. if F025<0
replace protestant=1 if F025==62

gen other_religions=0
replace other_religions=. if F025<0 
replace other_religions=1 if F025==0 & (non_religious==0)
replace other_religions=1 if F025>0 & (non_religious==0 & catholic==0 & protestant==0)

*REFERENCE GROUP: ATHEISTS/NON-RELIGIOUS
*St Err are robust as there is only one country in the analysis
* See Fig 5.3 readme for more detail
mlogit parenting catholic protestant other_religions college compl_highsc age age_sq female i.wave  [pweight=S017], r base(1)  base

* population shares 
tab catholic if e(sample)
tab protestant if e(sample)
tab other_religions if e(sample)
tab non_religious if e(sample)

*REFERENCE CATEGORY TO PREPARE THE TABLE FOR THE CHAPTER
tab parenting if non_religious==1 & e(sampe)

**********************************************
*RELIGION IN GENERAL, p. 177
******************************

use WVS_OECD, clear

*Classified as religious those individuals stating that religion is Very Important or Rather Important
tab A006,m

gen imp_religion=(A006==1|A006==2)
replace imp_religion=. if A006<0
tab imp_religion,m

mlogit parenting  imp_religion college compl_highsc age age_sq female lgdp_pc_pwt i.country_num i.wave if oecd_founders==1  [pweight=S017], vce(cluster country) base(1) base rrr 

**********************************************
*ALL RELIGIONS, p. 179 
******************************

clear all
use WVS_OECD

*Information about Religiosity is not collected in Wave 1

gen non_religious=0 if A006!=-4
replace non_religious=. if F025<0
replace non_religious=. if wave==1
replace non_religious=1 if F025==0 & (A006==3|A006==4)

*CATHOLIC
gen catholic=0
replace catholic=. if F025<0
replace catholic=1 if F025==15|F025==29|F025==64

*OTHER CHRISTIAN (Protestant, Orthodox etc.)
gen other_christian=0
replace other_christian=. if F025<0
replace other_christian=1 if F025==62|F025==52|F025==5|F025==7|F025==19|F025==20|F025==46|F025==61|F025==66|F025==68|F025==78|F025==89| ///
F025==360001|F025==528001|F025==528002|F025==17|F025==28|F025==55|F025==18|F025==30|F025==44|F025==51|F025==81|F025==25|F025==48|F025==9|F025==60

*MUSLIM
gen muslim=0
replace muslim=. if F025<0
replace muslim=1 if F025==49

*BUDDHIST
gen buddhist=0
replace buddhist=. if F025<0
replace buddhist=1 if F025==12

*OTHER RELIGIONS
gen other_religions=0
replace other_religions=. if F025<0 
replace other_religions=1 if F025==0 & (non_religious==0)
replace other_religions=1 if F025>0 & (non_religious==0 & catholic==0 & other_christian==0 & muslim==0 & buddhist==0)


*REFERENCE GROUP: ATHEISTS/NON RELIGIOUS
mlogit parenting  catholic other_christian muslim buddhist other_religions college compl_highsc age age_sq female lgdp_pc_pwt i.country_num i.wave if wave>1 & oecd_founders==1  [pweight=S017], vce(cluster country) base(1) base rrr

*******************************************
*POLITICAL ORIENTATION, p. 180
******************************
clear all
use WVS_OECD

tab E033,m
label list E033

gen left=(E033>=1 & E033<=3)
replace left=. if E033<-1
gen centre=(E033>=4 & E033<=7)
replace centre=. if E033<-1
gen right=(E033>=8 & E033<=10)
replace right=. if E033<-1
gen undecided=(E033==-1)
replace undecided=. if E033<-1

tab left,m
tab centre,m
tab right,m
tab undecided,m

tab X045,m
 
gen social_class=X045 
replace social_class=. if X045<1
tab social_class,m
 
gen sc_upper=(social_class==1) if social_class!=.
gen sc_upmid=(social_class==2) if social_class!=.
gen sc_lowmid=(social_class==3) if social_class!=.
gen sc_workcl=(social_class==4) if social_class!=.
gen sc_lower=(social_class==5) if social_class!=.


* REgression
mlogit parenting centre right undecided college compl_highsc age age_sq female lgdp_pc_pwt i.country_num i.wave  [pweight=S017] if oecd_founders==1, vce(cluster country) base(1) base 
